==> qore-0.8.13.8.tar.bz2: qore-0.8.13.8/docs/modules/MailMessage/html/navtreedata.js <==
/*
@ @licstart  The following is the entire license notice for the
JavaScript code in this file.

Copyright (C) 1997-2017 by Dimitri van Heesch

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

You should have received a copy of the GNU General Public License along
with this program; if not, write to the Free Software Foundation, Inc.,
51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.

@licend  The above is the entire license notice
for the JavaScript code in this file
*/
var NAVTREE =
[
  [ "Qore MailMessage Module Reference", "index.html", [
    [ "MailMessage Module", "index.html", [
      [ "MailMessage Module Introduction", "index.html#mailmessageintro", null ],
      [ "MailMessage Release Notes", "index.html#mailmessage_relnotes", [
        [ "mailmessage_v1_3_1", "index.html#mailmessage_v1_3_1", null ],
        [ "mailmessage_v1_3", "index.html#mailmessage_v1_3", null ],
        [ "mailmessage_v1_2_1", "index.html#mailmessage_v1_2_1", null ],
        [ "mailmessage_v1_2", "index.html#mailmessage_v1_2", null ],
        [ "mailmessage_v1_1", "index.html#mailmessage_v1_1", null ],
        [ "mailmessage_v1_0_4", "index.html#mailmessage_v1_0_4", null ],
        [ "mailmessage_v1_0_3", "index.html#mailmessage_v1_0_3", null ],
        [ "mailmessage_v1_0_2", "index.html#mailmessage_v1_0_2", null ],
        [ "mailmessage_v1_0_1", "index.html#mailmessage_v1_0_1", null ],
        [ "mailmessage_v1_0", "index.html#mailmessage_v1_0", null ]
      ] ]
    ] ],
    [ "Modules", "modules.html", "modules" ],
    [ "Namespaces", "namespaces.html", [
      [ "Namespace List", "namespaces.html", "namespaces_dup" ],
      [ "Namespace Members", "namespacemembers.html", [
        [ "All", "namespacemembers.html", null ],
        [ "Variables", "namespacemembers_vars.html", null ]
      ] ]
    ] ],
    [ "Classes", "annotated.html", [
      [ "Class List", "annotated.html", "annotated_dup" ],
      [ "Class Index", "classes.html", null ],
      [ "Class Hierarchy", "hierarchy.html", "hierarchy" ],
      [ "Class Members", "functions.html", [
        [ "All", "functions.html", null ],
        [ "Functions", "functions_func.html", null ],
        [ "Variables", "functions_vars.html", null ]
      ] ]
    ] ]
  ] ]
];

var NAVTREEINDEX =
[
"annotated.html",
"group__database__driver__constants.html#ga3e14e0949befa85b7c2993dd7a369811",
"group__event__constants.html",
"group__list__functions.html#gaf8c5fe3ac64fac2eab1f17d0b032d368",
"group__option__constants.html#ga518fbbbde3df9c996bbba1d207c5ae10",
"group__string__functions.html#gab2ccb59779f7860a4e67af5b5a3bc766",
"group__x509__verification__constants.html#ga86aaa114c74aab441847ad4db7597a6f"
];

var SYNCONMSG = 'click to disable panel synchronisation';
var SYNCOFFMSG = 'click to enable panel synchronisation';

==> qore-0.9.2.tar.bz2: qore-0.9.2/docs/modules/MailMessage/html/navtreedata.js <==
/*
@ @licstart  The following is the entire license notice for the
JavaScript code in this file.

Copyright (C) 1997-2017 by Dimitri van Heesch

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

You should have received a copy of the GNU General Public License along
with this program; if not, write to the Free Software Foundation, Inc.,
51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.

@licend  The above is the entire license notice
for the JavaScript code in this file
*/
var NAVTREE =
[
  [ "Qore MailMessage Module Reference", "index.html", [
    [ "MailMessage Module", "index.html", [
      [ "MailMessage Module Introduction", "index.html#mailmessageintro", null ],
      [ "MailMessage Release Notes", "index.html#mailmessage_relnotes", [
        [ "mailmessage_v1_3_1", "index.html#mailmessage_v1_3_1", null ],
        [ "mailmessage_v1_3", "index.html#mailmessage_v1_3", null ],
        [ "mailmessage_v1_2_1", "index.html#mailmessage_v1_2_1", null ],
        [ "mailmessage_v1_2", "index.html#mailmessage_v1_2", null ],
        [ "mailmessage_v1_1", "index.html#mailmessage_v1_1", null ],
        [ "mailmessage_v1_0_4", "index.html#mailmessage_v1_0_4", null ],
        [ "mailmessage_v1_0_3", "index.html#mailmessage_v1_0_3", null ],
        [ "mailmessage_v1_0_2", "index.html#mailmessage_v1_0_2", null ],
        [ "mailmessage_v1_0_1", "index.html#mailmessage_v1_0_1", null ],
        [ "mailmessage_v1_0", "index.html#mailmessage_v1_0", null ]
      ] ]
    ] ],
    [ "Modules", "modules.html", "modules" ],
    [ "Namespaces", "namespaces.html", [
      [ "Namespace List", "namespaces.html", "namespaces_dup" ],
      [ "Namespace Members", "namespacemembers.html", [
        [ "All", "namespacemembers.html", null ],
        [ "Variables", "namespacemembers_vars.html", null ]
      ] ]
    ] ],
    [ "Classes", "annotated.html", [
      [ "Class List", "annotated.html", "annotated_dup" ],
      [ "Class Index", "classes.html", null ],
      [ "Class Hierarchy", "hierarchy.html", "hierarchy" ],
      [ "Class Members", "functions.html", [
        [ "All", "functions.html", null ],
        [ "Functions", "functions_func.html", null ],
        [ "Variables", "functions_vars.html", null ]
      ] ]
    ] ]
  ] ]
];

var NAVTREEINDEX =
[
"annotated.html",
"group__astparser__symbol__usage__kind__constants.html#ga70c7f88b4dbf1a996baea83919432607",
"group__dbi__capabilities.html#ga9edf0826e734f77115fd8f1001cf4a9e",
"group__filesystem__functions.html#ga59c7b40bb68308943c26473b3536594d",
"group__misc__functions.html#ga0c3bdfd8fb3a29af0d3bcd0ed3a05eb0",
"group__parse__options.html#gaa5aaa3b96f4662b3c49bed1d1ab8ec88",
"group__tattr__control__character__constants.html#gaee9526a9d666c265e0ca0d00dd41a2be"
];

var SYNCONMSG = 'click to disable panel synchronisation';
var SYNCOFFMSG = 'click to enable panel synchronisation';
